@@ -1,7 +1,7 @@
 pub mod auth;
 pub mod host_with_port;
 pub mod param;
-pub mod schema;
+pub mod scheme;
 
 #[doc(hidden)]
 pub use tokenizer::Tokenizer;
@@ -9,8 +9,9 @@ pub use tokenizer::Tokenizer;
 pub use auth::Auth;
 pub use host_with_port::{Domain, Host, HostWithPort, Port};
 pub use param::Param;
-pub use schema::Schema;
+pub use scheme::Scheme;
 
+use crate::Transport;
 use std::convert::{TryFrom, TryInto};
 
 /// A very flexible SIP(S) URI.
@@ -21,7 +22,7 @@ use std::convert::{TryFrom, TryInto};
 /// Similarly on generation, if no port is specified, no port is set at all in the final string.
 #[derive(Debug, PartialEq, Eq, Clone)]
 pub struct Uri {
-    pub schema: Option<Schema>,
+    pub scheme: Option<Scheme>,
     pub auth: Option<Auth>,
     pub host_with_port: HostWithPort,
     pub params: Vec<Param>,
@@ -40,13 +41,20 @@ impl Uri {
     pub fn port(&self) -> Option<&Port> {
         self.host_with_port.port.as_ref()
     }
+
+    pub fn transport(&self) -> Option<&Transport> {
+        self.params.iter().find_map(|param| match param {
+            Param::Transport(transport) => Some(transport),
+            _ => None,
+        })
+    }
 }
 
 //TODO: improve impl here to remove clones
 impl std::fmt::Display for Uri {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
-        let schema = match &self.schema {
-            Some(schema) => format!("{}:", schema),
+        let scheme = match &self.scheme {
+            Some(scheme) => format!("{}:", scheme),
             None => format!(""),
         };
         let auth = match &self.auth {
@@ -57,7 +65,7 @@ impl std::fmt::Display for Uri {
         write!(
             f,
             "{}{}{}{}",
-            schema,
+            scheme,
             auth,
             self.host_with_port,
             self.params
@@ -88,7 +96,7 @@ impl TryFrom<&str> for Uri {
 impl Default for Uri {
     fn default() -> Self {
         Self {
-            schema: Default::default(),
+            scheme: Default::default(),
             host_with_port: Default::default(),
             auth: None,
             params: Default::default(),
@@ -100,7 +108,7 @@ impl Default for Uri {
 impl From<HostWithPort> for Uri {
     fn from(host_with_port: HostWithPort) -> Self {
         Self {
-            schema: Default::default(),
+            scheme: Default::default(),
             host_with_port,
             auth: None,
             params: Default::default(),
@@ -109,10 +117,10 @@ impl From<HostWithPort> for Uri {
     }
 }
 
-impl From<(Schema, Host)> for Uri {
-    fn from(tuple: (Schema, Host)) -> Self {
+impl From<(Scheme, Host)> for Uri {
+    fn from(tuple: (Scheme, Host)) -> Self {
         Self {
-            schema: Some(tuple.0),
+            scheme: Some(tuple.0),
             host_with_port: tuple.1.into(),
             auth: None,
             params: Default::default(),
@@ -124,7 +132,7 @@ impl From<(Schema, Host)> for Uri {
 impl From<std::net::SocketAddr> for Uri {
     fn from(socket_addr: std::net::SocketAddr) -> Self {
         Self {
-            schema: Default::default(),
+            scheme: Default::default(),
             host_with_port: socket_addr.into(),
             auth: None,
             params: Default::default(),
@@ -136,7 +144,7 @@ impl From<std::net::SocketAddr> for Uri {
 impl From<std::net::IpAddr> for Uri {
     fn from(ip_addr: std::net::IpAddr) -> Self {
         Self {
-            schema: Default::default(),
+            scheme: Default::default(),
             host_with_port: ip_addr.into(),
             auth: None,
             params: Default::default(),
@@ -147,7 +155,7 @@ impl From<std::net::IpAddr> for Uri {
 
 #[doc(hidden)]
 pub mod tokenizer {
-    use super::{auth, host_with_port, param, schema, Uri};
+    use super::{auth, host_with_port, param, scheme, Uri};
     use crate::{Error, NomError};
     use std::convert::TryInto;
 
@@ -156,7 +164,7 @@ pub mod tokenizer {
 
         fn try_into(self) -> Result<Uri, Error> {
             Ok(Uri {
-                schema: self.schema.map(TryInto::try_into).transpose()?,
+                scheme: self.scheme.map(TryInto::try_into).transpose()?,
                 auth: self.auth.map(TryInto::try_into).transpose()?,
                 host_with_port: self.host_with_port.try_into()?,
                 params: self
@@ -171,7 +179,7 @@ pub mod tokenizer {
 
     #[derive(Debug, PartialEq, Eq, Clone)]
     pub struct Tokenizer<'a> {
-        pub schema: Option<schema::Tokenizer<'a>>,
+        pub scheme: Option<scheme::Tokenizer<'a>>,
         pub auth: Option<auth::Tokenizer<'a>>,
         pub host_with_port: host_with_port::Tokenizer<'a>,
         pub params: Vec<param::Tokenizer<'a>>,
@@ -183,7 +191,7 @@ pub mod tokenizer {
         pub fn tokenize(part: &'a [u8]) -> Result<(&'a [u8], Self), NomError<'a>> {
             use nom::{character::complete::space0, combinator::opt, multi::many0};
 
-            let (rem, schema) = opt(schema::Tokenizer::tokenize)(part)?;
+            let (rem, scheme) = opt(scheme::Tokenizer::tokenize)(part)?;
             let (rem, auth) = opt(auth::Tokenizer::tokenize)(rem)?;
             let (rem, host_with_port) = host_with_port::Tokenizer::tokenize(rem)?;
             let (rem, params) = many0(param::Tokenizer::tokenize)(rem)?;
@@ -193,7 +201,7 @@ pub mod tokenizer {
             Ok((
                 rem,
                 Self {
-                    schema,
+                    scheme,
                     auth,
                     host_with_port,
                     params,
@@ -206,14 +214,14 @@ pub mod tokenizer {
         pub fn tokenize_without_params(part: &'a [u8]) -> Result<(&'a [u8], Self), NomError<'a>> {
             use nom::combinator::opt;
 
-            let (rem, schema) = opt(schema::Tokenizer::tokenize)(part)?;
+            let (rem, scheme) = opt(scheme::Tokenizer::tokenize)(part)?;
             let (rem, auth) = opt(auth::Tokenizer::tokenize)(rem)?;
             let (rem, host_with_port) = host_with_port::Tokenizer::tokenize(rem)?;
 
             Ok((
                 rem,
                 Self {
-                    schema,
+                    scheme,
                     auth,
                     host_with_port,
                     params: vec![],
